MihDateField class
A customized date selection field that integrates with showDatePicker.
The MihDateField provides a stylized wrapper around a read-only TextFormField. When tapped, it opens the system date picker and formats the result into the provided controller.
It features:
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MihDateField
Constructors
-
MihDateField({Key? key, required TextEditingController controller, required String labelText, required bool required, Color? primaryColor, Color? secondayColor, double? width, double? height, double? borderRadius, double? elevation, bool? darkMode, FormFieldValidator<
String> ? validator}) -
const
Properties
- borderRadius → double?
-
The radius of the input field corners. Defaults to 8.0.
final
- controller → TextEditingController
-
The controller that handles the text being edited.
final
- darkMode → bool?
-
Whether to use Dark Mode styling. If null, MihColors defaults to dark.
final
- elevation → double?
-
The elevation of the input field material. Defaults to 4.0.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
The height of the entire widget.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelText → String
-
The text to display above the input field.
final
- primaryColor → Color?
-
The primary color of the date picker
final
- required → bool
-
Whether this field is mandatory.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondayColor → Color?
-
The secondary color of the date picker
final
-
validator
→ FormFieldValidator<
String> ? -
An optional method that validates an input.
final
- width → double?
-
The width of the entire widget.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MihDateField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited